package adminkindbox

import (
	"git.gocasts.ir/ebhomengo/niki/entity"
	param "git.gocasts.ir/ebhomengo/niki/param/admin/kind_box"
	errmsg "git.gocasts.ir/ebhomengo/niki/pkg/err_msg"
	richerror "git.gocasts.ir/ebhomengo/niki/pkg/rich_error"
	"github.com/go-ozzo/ozzo-validation/is"
	validation "github.com/go-ozzo/ozzo-validation/v4"
)

func (v Validator) ValidateUpdateRequest(req param.KindBoxUpdateRequest) (map[string]string, error) {
	const op = "adminkindbox.ValidateUpdateRequest"

	if err := validation.ValidateStruct(&req,
		validation.Field(&req.BenefactorID,
			validation.Required,
			validation.By(v.doesBenefactorExist(req.BenefactorID))),

		validation.Field(&req.KindBoxID,
			validation.Required,
			validation.By(v.doesKindBoxExist(req.BenefactorID)),
			validation.By(v.doesKindBoxBelongToBenefactor(req.BenefactorID, req.KindBoxID))),

		validation.Field(&req.SerialNumber, is.Alphanumeric),

		validation.Field(&req.TotalAmount, validation.Min(0)),

		validation.Field(&req.SenderID,
			validation.By(v.doesEmployeeExist(req.SenderID))),

		validation.Field(&req.ReceiverID,
			validation.By(v.doesEmployeeExist(req.ReceiverID))),

		validation.Field(&req.Status,
			validation.In(entity.AllKindBoxStatus())),
	); err != nil {
		fieldErrors := make(map[string]string)

		errV, ok := err.(validation.Errors)
		if ok {
			for key, value := range errV {
				if value != nil {
					fieldErrors[key] = value.Error()
				}
			}
		}

		return fieldErrors, richerror.New(op).
			WithMessage(errmsg.ErrorMsgInvalidInput).
			WithKind(richerror.KindInvalid).
			WithMeta(map[string]interface{}{"req": req}).
			WithErr(err)
	}

	return nil, nil
}
